Awesome Medical Imaging Datasets (AMID) - a curated list of medical imaging datasets with unified interfaces

# Install

Just get it from PyPi:

```shell
pip install amid
```

Or if you want to use version control features:

```shell
git clone https://github.com/neuro-ml/amid.git
cd amid && pip install -e .
```
